@@ -6,17 +6,19 @@ use Perl6::Perldoc::Parser;
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 sub new {
     my ($package, %self) = @_;
     return bless \%self, $package;
 }
 
-sub render {
+sub render_file {
     my ($self, $file, $format) = @_;
 
-    die "Format $format unsupported" if $format !~ /^(?:ansi|text|xhtml)$/;
+    if ($format !~ /^(?:ansi|text|xhtml)$/) {
+        die __PACKAGE__ . " doesn't support the '$format' format";
+    }
     eval "require Perl6::Perldoc::To::\u$format";
     die $@ if $@;
 
@@ -26,6 +28,15 @@ sub render {
                                  ->$method();
 }
 
+sub render_string {
+    my ($self, $string, $format) = @_;
+
+    open my $handle, '<', \$string or die "Can't open input filehandle: $!";
+    my $result = $self->render_file($handle, $format);
+    close $handle;
+    return $result;
+}
+
 1;
 
 =encoding UTF-8
@@ -40,12 +51,18 @@ App::Grok::Pod6 - A Pod 6 backend for grok
 
 This is the constructor. It currently takes no arguments.
 
-=head2 C<render>
+=head2 C<render_file>
 
 Takes two arguments, a filename and the name of an output format. Returns
 a string containing the rendered document. It will C<die> if there is an
 error.
 
+=head2 C<render_string>
+
+Takes two arguments, a string and the name of an output format. Returns
+a string containing the rendered document. It will C<die> if there is an
+error.
+
 =head1 AUTHOR
 
 Hinrik Örn Sigurðsson, L<hinrik.sig@gmail.com>
